@@ -132,7 +132,7 @@ def aa_colors(amino_acid):
     return f"\033[38;5;{textcolor}m\033[48;5;{bkg_color}m{amino_acid}\033[0;0m"
 
 
-def get_uniprot_seqs(server, ensembl_ids):
+def get_uniprot_seqs(server, ensembl_ids, id_type="ensembl"):
     """
     Retrieve UniProt sequences based on Ensemsbl identifiers.
 
@@ -149,11 +149,23 @@ def get_uniprot_seqs(server, ensembl_ids):
     if type(ensembl_ids) == str:
         ensembl_ids = [ensembl_ids]
 
+    # Define Ensembl ID type
+    if id_type == "ensembl":
+        ens_id_type = "ENSEMBL_TRS_ID"
+    elif id_type == "flybase":
+        ens_id_type = "FLYBASE_ID"
+    elif id_type == "wormbase":
+        ens_id_type = "WORMBASE_TRS_ID"
+    else:
+        raise ValueError(
+            f"ID type defined as {id_type}. Expected one of: ensembl, flybase, wormbase"
+        )
+
     # Define query arguments
     # Columns documentation: https://www.uniprot.org/help/uniprotkb%5Fcolumn%5Fnames
     # from/to IDs documentation: https://www.uniprot.org/help/api_idmapping
     query_args = {
-        "from": "ENSEMBL_TRS_ID",
+        "from": ens_id_type,
         "to": "ACC",
         "format": "tab",
         "query": " ".join(ensembl_ids),
@@ -218,7 +230,7 @@ def get_uniprot_seqs(server, ensembl_ids):
     return df
 
 
-def get_uniprot_info(server, ensembl_id, id_type):
+def get_uniprot_info(server, ensembl_id, id_type, verbose=True):
     """
     Retrieve UniProt synonyms and description based on Ensemsbl identifiers.
 
@@ -234,6 +246,13 @@ def get_uniprot_info(server, ensembl_id, id_type):
         ens_id_type = "ENSEMBL_ID"
     elif id_type == "Transcript":
         ens_id_type = "ENSEMBL_TRS_ID"
+    elif id_type == "Flybase":
+        ens_id_type = "FLYBASE_ID"
+    elif id_type == "WB_Gene":
+        ens_id_type = "WORMBASE_ID"
+    elif id_type == "WB_Transcript":
+        ens_id_type = "WORMBASE_TRS_ID"
+
     else:
         logging.warning(
             f"Ensembl_ID '{ensembl_id}' was not recognized as either gene nor transcript. Gene name synonyms and description will not be fetched from UniProt."
@@ -307,16 +326,18 @@ def get_uniprot_info(server, ensembl_id, id_type):
 
         # If there are reviewed results, return only reviewed results
         if "reviewed" in df["status"].values:
-            logging.info(
-                f"Returning only reviewed UniProt results for Ensembl ID {ensembl_id}."
-            )
+            if verbose is True:
+                logging.info(
+                    f"Returning only reviewed UniProt results for Ensembl ID {ensembl_id}."
+                )
             # Only keep rows where status is "reviewed"
             df = df[df.status == "reviewed"]
 
         else:
-            logging.warning(
-                f"No reviewed UniProt results were found for Ensembl ID {ensembl_id}. Returning all unreviewed results."
-            )
+            if verbose is True:
+                logging.warning(
+                    f"No reviewed UniProt results were found for Ensembl ID {ensembl_id}. Returning all unreviewed results."
+                )
         # Return set of all results if more than one UniProt ID was found for this Ensembl ID
         if len(df) > 1:
             final_df = pd.DataFrame()
